@@ -5,7 +5,7 @@ import json
 import re
 from ccjob.templates import defaults
 from ccjob.queue import queue_factory
-from ccjob.utils import split_path
+from ccjob.utils import split_path, module_exists
 
 class Input(object):
     def __init__(self, fpath, inp_string=None, to_file=True):
@@ -260,7 +260,7 @@ class Job(object):
             # manual implementation of has_finished
             if success_fct == None:
                 with open(path_to_outfile) as out:
-                    for i, line in out:
+                    for line in out:
                         if success_string in line:
                             normal = True
             else:
